add_in_nbs() adds a logical column called in_nbs that indicates whether
the individual in a row has a match in NBS using their first name, last name,
date of birth, and test date. The resulting in_nbs column is:
TRUE if a match is found (including NA == NA)
FALSE if no match is found with complete data
NA if no match is found with incomplete data
add_in_nbs(crf = distinct_crf(), nbs = load_positive())
| crf | Case Report Form data, usually from
|
|---|---|
| nbs | Positive NBS data from
|
The input crf data with a logical column in_nbs added