filter_crf() filters out cases which have previously answered the survey
or were not at work within days days of their onset/test date.
filter_crf(data = download_crf(), days = 5L, na_keep = TRUE)
| data | A data frame with data from the CRF REDcap project, as output by
|
|---|---|
| days | The maxmimum allowed difference between last day worked
( |
| na_keep | Should missing data be kept or excluded? |
The input data filtered according to the description above