save_crf_wb() saves the output of
create_crf_wb() to the specified
directory under the file name crf_nbs_overlap_YYYY-MM-DD.xlsx, where
YYYY-MM-DD is the date at the time of saving.
save_crf_wb( wb = create_crf_wb(), dir = c("V:/OPERATIONS Surveillance Coordinator/Clusters/Case Report Forms/CRF_NBS"), force = TRUE )
| wb | An openxlsx |
|---|---|
| dir | The directory to save the file |
| force | Should an existing file at this location be overwritten? Unlike
most save functions in the covid* package universe, the default here is
|
The path to the saved file (invisibly)